from pathlib import Path
import os
import subprocess
import string
import re


path = str(Path().absolute())
executable = "\dist\MainCalculatorConsole.exe"
subprocess.call([path + executable])


#subprocess.call(["C:\Users\Ari Bautista\Videos\Calculadora_Clases\dist\MainCalculatorConsole.exe"])





import pickle
import tkinter as tk

#Encapsulamiento de GUI de Tkinder
class Multiplicar():
    def __init__(self, master, num1, num2):
        self.master = master
        var1 = tk.DoubleVar()
        t1 = tk.Entry(master, textvariable=var1)
        t1.pack()

        var2 = tk.DoubleVar()
        t2 = tk.Entry(master, textvariable=var2)
        t2.pack()

        result = tk.DoubleVar()
        l = tk.Label(master, textvariable=result)
        l.pack()

        #Configurar las variables
        var1.set(num1)
        var2.set(num2)
        
        result.set(var1.get() * var2.get())
        
#Main function
def main(number_1, number_2): 

    root = tk.Tk()
    root.title('Multiplicar')
    root.geometry("300x300")
    app = Multiplicar(root, number_1, number_2)
    root.mainloop()

if __name__ == '__main__':
    main()


import pickle
import CalculatorSuma
import CalculatorResta
import CalculatorMultiplicar
import CalculatorDivision

print("Calculadora De Escritorio")
print("Suma = 1")
print("Resta = 2")
print("Multiplicacion = 3")
print("Division = 4")

operator = int(input('Selecciona Operacion Aritmetica: '))

if operator == 1:
    number_1 = float(input('Enter your first number: '))
    number_2 = float(input('Enter your second number: '))
    CalculatorSuma.main(number_1, number_2)
     
if operator == 2:
    number_1 = float(input('Enter your first number: '))
    number_2 = float(input('Enter your second number: '))
    CalculatorResta.main(number_1, number_2)

if operator == 3:
    number_1 = float(input('Enter your first number: '))
    number_2 = float(input('Enter your second number: '))
    CalculatorMultiplicar.main(number_1, number_2)

if operator == 4:
    number_1 = float(input('Enter your first number: '))
    number_2 = float(input('Enter your second number: '))
    CalculatorDivision.main(number_1, number_2)

else:
    print("El numero insertado no es valido...")

